#[async_executor]Expand description
Generates the appropriate async main executor attribute based on feature flags:
- If “tokio” feature is enabled: generates
#[tokio::main] - If “futures” feature is enabled: generates
#[apply(main!)]
#[async_executor]Generates the appropriate async main executor attribute based on feature flags:
#[tokio::main]#[apply(main!)]