#[async_test]Expand description
Generates the appropriate async test attribute based on feature flags:
- If “tokio” feature is enabled: generates
#[tokio::test] - If “futures” feature is enabled: generates
#[apply(test!)]
#[async_test]Generates the appropriate async test attribute based on feature flags:
#[tokio::test]#[apply(test!)]